[![image](http://img.shields.io/badge/arXiv-2207.01627-orange.svg?style=flat)](https://arxiv.org/abs/2505.22718)

# About 

A pipeline for the computation of the angular power spectrum beyond the Limber approximation. We offer a wide range of probes such as galaxy clustering, including magnification bias, redshift-space distortions and primordial non-Gaussianity, weak lensing, including intrinsic alignment, CMB lensing and CMB integrated Sachs-Wolfe effect. 

If you use parts of the code presented here for your research, cite
(Reymond et al. ,
[arXiv-2505.22718](https://arxiv.org/abs/2505.22718)).

## Installation
clone this repo and install it as a Python package using `pip`:
```
git clone https://cosmo-gitlab.phys.ethz.ch/cosmo_public/swiftcl
cd swiftcl 
pip install -e .
```

## Contributions
If you want to contribute, please open an issue.